.. _bibliography:

============
Bibliography
============
.. [Nouy2017book] A. Nouy, *Chapter 4: Low-Rank Methods for High-Dimensional Approximation and Model Order Reduction*. Model Reduction and Approximation. 
    SIAM, Philadelphia, PA, p 171-226, 2017. 
    `pdf <https://arxiv.org/pdf/1511.01554.pdf>`__
.. [Falco2018] A. Falco, W. Hackbusch, and A. Nouy, *Tree-based tensor formats*
    SeMA Journal, Oct 2018.
    `pdf <https://arxiv.org/pdf/1810.01262.pdf>`__
.. [Grelier2018] E. Grelier, A. Nouy, and M. Chevreuil, *Learning with tree-based tensor formats*, ArXiv eprints, arXiv:1811.04455,  November 2018.
    `pdf <https://arxiv.org/pdf/1811.04455.pdf>`__
.. [Grelier2019] E. Grelier, A. Nouy, and R. Lebrun,
    *Learning high-dimensional probability distributions using tree tensor*, ArXiv eprints, arXiv:1912.07913, 2019.
    `pdf <https://arxiv.org/pdf/1912.07913.pdf>`__
.. [Michel2020] B. Michel and A. Nouy, *Learning with tree tensor networks: complexity estimates and model selection*, ArXiv eprints, arXiv:2007.01165, 2019.
    `pdf <https://arxiv.org/pdf/2007.01165.pdf>`__
.. [Ali2020I] M. Ali and A. Nouy., *Approximation with tensor networks. part I: Approximation spaces.* ArXiv eprints, arXiv:2007.00118, 2020. 
    `pdf <https://arxiv.org/pdf/2007.00118.pdf>`__
.. [Ali2020II] M. Ali and A. Nouy., *Approximation with tensor networks. part II: Approximation rates for smoothness classes*, ArXiv eprints, arXiv:2007.00128, 2020.
    `pdf <https://arxiv.org/pdf/2007.00128.pdf>`__
.. [Ali2021III] M. Ali and A. Nouy., *Approximation with tensor networks. part III: Multivariate Approximation*, ArXiv eprints, arXiv:2101.11932, 2021.
    `pdf <https://arxiv.org/abs/2101.11932>`__
.. [Nouy2017hopca] A. Nouy,
    *Higher-order principal component analysis for the approximation of tensors in tree-based low-rank formats*. Numerische Mathematik, 2019, vol. 141, no 3, p. 743-789, 2019.
    `pdf <https://arxiv.org/pdf/1705.00880.pdf>`__
.. [Hackbusch2019] W. Hackbusch, *Tensor Spaces and Numerical Tensor Calculus*,
    Springer Nature, 2019, volume~56.
